/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jsp.taglib.util;

import com.squeakysand.commons.lang.MathUtils;
import com.squeakysand.commons.lang.ToStringHelper;
import com.squeakysand.jsp.tagext.EnhancedSimpleTagSupport;
import com.squeakysand.jsp.tagext.VariableScope;
import com.squeakysand.jsp.tagext.annotations.JspTag;
import com.squeakysand.jsp.tagext.annotations.JspTagAttribute;
import com.squeakysand.jsp.tagext.annotations.JspTagVariable;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Generates a random integer value and injects it into the page for later use.
 * 
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
@JspTag(name = "randomInt")
public class RandomIntegerGeneratorTag extends EnhancedSimpleTagSupport {

    private static final Logger LOG = LoggerFactory.getLogger(RandomIntegerGeneratorTag.class);

    private Integer max;
    private Integer min;
    private String var;

    @Override
    public void doTag() throws JspException, IOException {
        if (LOG.isDebugEnabled()) {
            LOG.debug(ToStringHelper.toString(this));
        }
        Integer result = MathUtils.random(min, max);
        setPageAttribute(var, result);
    }

    /**
     * Accessor for the <code>max</code> property.
     * 
     * @return the current value of the <code>max</code> property.
     */
    public Integer getMax() {
        return max;
    }

    /**
     * Accessor for the <code>min</code> property.
     * 
     * @return the current value of the <code>min</code> property.
     */
    public Integer getMin() {
        return min;
    }

    /**
     * Accessor for the <code>var</code> property.
     * 
     * @return the current value of the <code>var</code> property.
     */
    public String getVar() {
        return var;
    }

    /**
     * The maximum value of the random value to be generated.
     * 
     * @param max the maximum allowed value, defaults to {@link Integer#MAX_VALUE} if no value is supplied.
     */
    @JspTagAttribute(rtexprvalue = true)
    public void setMax(Integer max) {
        this.max = max;
    }

    /**
     * The minimum value of the random value to be generated.
     * 
     * @param min the minimum allowed value, defaults to {@link Integer#MIN_VALUE} if no value is supplied.
     */
    @JspTagAttribute(rtexprvalue = true)
    public void setMin(Integer min) {
        this.min = min;
    }

    /**
     * The name of the context variable to inject into the page.
     * 
     * @param var the name of the context variable to inject into the page.
     */
    @JspTagVariable(scope = VariableScope.AT_END, variableClass = Integer.class)
    @JspTagAttribute(required = true)
    public void setVar(String var) {
        this.var = var;
    }

}
